package com.hungraim.ltc.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.hungraim.ltc.pojo.entity.eval.ChAprEmp;
import com.hungraim.ltc.pojo.entity.eval.ChAprReport;
import com.hungraim.ltc.pojo.vo.assessment.TaskDistributionVO;
import com.hungraim.ltc.pojo.vo.assessment.TaskReportVO;
import com.hungraim.ltc.service.TaskService;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.List;

/**
 * 失能评定Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.assessment/task")
@Slf4j
public class TaskController {

    @Autowired
    private TaskService taskService;

    /**
     * 评定任务分配、查询列表
     *
     * @param organId       适用机构代码
     * @param provincial    所在省
     * @param city          所在市
     * @param area          所在区域
     * @param street        所在街道
     * @param realName      失能人员姓名
     * @param certiCode     失能人员身份证号码
     * @param taskName      评定人员姓名
     * @param taskTel       评定人员手机号码
     * @param daysRemaining 评定剩余天数
     * @param status        任务状态
     * @param isReturn      是否退回
     * @param pageNum       当前页
     * @param pageSize      每页几条数据
     */
    @RequestMapping("/taskDistributionList")
    public Result<List<TaskDistributionVO>> taskDistributionList(String organId, String provincial, String city,
                                                                 String street, String realName, String certiCode, String taskName, String taskTel,
                                                                 String daysRemaining, String status, String isReturn, String area,
                                                                 int pageNum, int pageSize) {
        IPage<TaskDistributionVO> iPage = taskService.taskDistributionList(organId, provincial, city,
                street, realName, certiCode, taskName, taskTel, daysRemaining, status, isReturn, area,
                pageNum, pageSize);
        return Result.success(iPage.getRecords());
    }

    /**
     * 评定报告录入列表
     */
    @RequestMapping("/taskReportList")
    public Result<List<TaskReportVO>> taskReportList() {
        List<TaskReportVO> taskReportList = taskService.taskReportList();
        return Result.success(taskReportList);
    }

    /**
     * 查询失能人员列表
     */
    @RequestMapping("/aprEmpList")
    public Result<List<ChAprEmp>> aprEmpList() {
        List<ChAprEmp> chAprEmps = taskService.aprEmpList();
        return Result.success(chAprEmps);
    }

    /**
     * 评定报告新增
     */
    @RequestMapping("/addReport")
    public Result addReport(@RequestBody ChAprReport chAprReport) {
        chAprReport.setEffTime(new Date());
        taskService.addReport(chAprReport);
        return Result.success();
    }

    /**
     * 评定报告修改
     */
    @RequestMapping("/updateReport")
    public Result updateReport(String reportId, Integer disableLevelId, String polNo, String remark) {
        taskService.updateReport(reportId, disableLevelId, polNo, remark);
        return Result.success();
    }

    /**
     * 评定任务分配
     */
    @RequestMapping("/allotTask")
    public Result allotTask(String taskId, String empId) {
        int cout = taskService.allotTask(taskId, empId);
        if (cout != 1) {
            //数据插入失败
            return Result.failed();
        }
        return Result.success();
    }

}
